@@ -555,11 +555,15 @@ class TrafficItem(CustomField):
             args['MinGapBytes'] = duration.fixed_seconds.gap
             self._configure_delay(duration.fixed_seconds.delay, args)
         elif duration.choice == 'burst':
-            args['Type'] = 'custom'
+            if duration.burst.bursts is not None \
+                    and int(duration.burst.bursts) > 0:
+                args['Type'] = 'burstFixedDuration'
+                args['RepeatBurst'] = duration.burst.bursts
+            else:
+                args['Type'] = 'custom'
             args['BurstPacketCount'] = duration.burst.packets
             args['MinGapBytes'] = duration.burst.gap
-            args[
-                'EnableInterBurstGap'] = True if duration.burst.gap > 0 else False
+            args['EnableInterBurstGap'] = True
             inter_burst_gap = duration.burst.inter_burst_gap
             if inter_burst_gap.choice is not None:
                 value = getattr(inter_burst_gap, inter_burst_gap.choice, None)
